class supply::baremetal::controller(
  $machine_ip                 = undef,
  $machine_hostname           = undef,
  $region_name                = 'RegionOne',

  $api_fqdn                   = undef,

  $controller_ips             = [],
  $controller_hostnames       = [],
  $controller_ids             = [],

  # Root CA certs
  $supply_pki_root_ca_cert    = undef,
  $supply_pki_supply_ca_cert  = undef,
  $supply_pki_supply_ca_chain = undef,

  # Certs for the API
  $supply_pki_api_cert        = undef,
  $supply_pki_api_key         = undef,
  $supply_pki_api_pem         = undef,

  # Certificate for THIS machine
  $supply_pki_machine_cert    = undef,
  $supply_pki_machine_key     = undef,
  $supply_pki_machine_pem     = undef,

  $pass_mysql_rootuser        = undef,
  $pass_mysql_backup          = undef,

  $pass_keystone_adminuser    = undef,
  $pass_keystone_db           = undef,
  $pass_keystone_messaging    = undef,
  $pass_keystone_credkey1     = undef,
  $pass_keystone_credkey2     = undef,
  $pass_keystone_fernkey1     = undef,
  $pass_keystone_fernkey2     = undef,

  $pass_haproxy_stats         = undef,
  $pass_nova_messaging        = undef,
  $pass_nova_keystoneauth     = undef,

  # Parameters for clustering, only available if multinode is on.
  $multinode                  = false,
  $vip_ip                     = undef,
){

  ::supply::openrc {'supply':
    username     => 'admin',
    project_name => 'admin',
    password     => $pass_keystone_adminuser,
    auth_fqdn    => $api_fqdn,
    region_name  => $region_name,
  }

  class { '::supply::pki':
    supply_pki_root_ca_cert    => $supply_pki_root_ca_cert,
    supply_pki_supply_ca_cert  => $supply_pki_supply_ca_cert,
    supply_pki_supply_ca_chain => $supply_pki_supply_ca_chain,
    supply_pki_api_cert        => $supply_pki_api_cert,
    supply_pki_api_key         => $supply_pki_api_key,
    supply_pki_api_pem         => $supply_pki_api_pem,
    supply_pki_machine_cert    => $supply_pki_machine_cert,
    supply_pki_machine_key     => $supply_pki_machine_key,
    supply_pki_machine_pem     => $supply_pki_machine_pem,
  }

  class { '::supply::sysctl': }

  class { '::supply::services::mysql::server':
    machine_ip           => $machine_ip,
    machine_hostname     => $machine_hostname,

    first_master_ip      => $machine_ip,

    pass_mysql_rootuser  => $pass_mysql_rootuser,
    pass_mysql_backup    => $pass_mysql_backup,

    controller_ips       => $controller_ips,
    controller_hostnames => $controller_hostnames,
  }

  class { '::supply::services::haproxy':
    machine_ip           => $machine_ip,
    controller_ips       => $controller_ips,
    controller_hostnames => $controller_hostnames,
    api_key_pem          => $supply_pki_api_pem,
    pass_haproxy_stats   => $pass_haproxy_stats,
  }

  class { '::supply::services::keystone':
    pass_keystone_adminuser => $pass_keystone_adminuser,
    pass_keystone_db        => $pass_keystone_db,
    pass_keystone_messaging => $pass_keystone_messaging,
    pass_keystone_credkey1  => $pass_keystone_credkey1,
    pass_keystone_credkey2  => $pass_keystone_credkey2,
    pass_keystone_fernkey1  => $pass_keystone_fernkey1,
    pass_keystone_fernkey2  => $pass_keystone_fernkey2,

    controller_ips          => $controller_ips,
    sql_host                => $machine_ip,
    api_fqdn                => $api_fqdn,
    region_name             => $region_name,
  }

#  if $multinode {
#    ::supply::services::vip {'openstack-vip':
#      vip_ip         = $vip_ip,
#      machine_ip     = $machine_ip,
#      controller_ips = $controller_ips,
#      controller_ids = $controller_ids,
#    }
#  }

#  class { 'supply::services::firewall_controller':
#    vip_ip         => $vip_ip,
#    controller_ips => $controller_ips,
#  }

#  class {'supply::services::haproxy':
#    machine_ip         = $machine_ip,
#    api_key_pem        = $api_key_pem,
#    pass_haproxy_stats = $pass_haproxy_stats,
#  }
}
