class supply::manifests::services::nova::compute(
  $machine_ip             = undef,
  $machine_hostname       = undef,
  $region_name            = 'RegionOne',
  $pass_nova_keystoneauth = undef,
  $pass_nova_messaging    = undef,
  $api_fqdn               = undef,
  $setup_controller       = false,
  $setup_compute          = false,
  $vip_ip                 = undef,
  $controller_ips         = [],
  $controller_hostnames   = [],
  $notif_rabbit_servers   = [],
  $use_dvr                = false,
  $disable_notifications  = false,
){

  if $setup_controller == false {
    if $use_dvr == true {
      haproxy::frontend { 'metadataproxyfe':
        mode      => 'http',
        bind      => { "127.0.0.1:8775" => [] },
        options   => [
          { 'use_backend' => 'metadatabe' },
        ]
      }
      haproxy::balancermember { 'metadatabm':
        listening_service => 'metadatabe',
        ipaddresses       => $controller_ips,
        server_names      => $controller_hostnames,
        ports             => 8775,
        options           => 'check check-ssl ssl verify'
      }
    }
  }

  # This is needed for Buster, so live migration can work
  package { 'apparmor':
    ensure => present,
    before => Class['::nova'],
  }

  class { '::nova':
    default_transport_url      => os_transport_url({
      'transport' => $messaging_default_proto,
      'hosts'     => fqdn_rotate($all_masters),
      'port'      => $messaging_default_port,
      'username'  => 'nova',
      'password'  => $pass_nova_messaging,
    }),
    notification_transport_url => $nova_notif_transport_url,
    rabbit_use_ssl         => $use_ssl,
    rabbit_ha_queues       => true,
    kombu_ssl_ca_certs     => $oci_pki_root_ca_file,
    amqp_sasl_mechanisms   => 'PLAIN',
    notification_driver    => $notification_driver,
    notify_on_state_change => 'vm_and_task_state',
    nova_public_key        => { type => 'ssh-rsa', key => $pass_nova_ssh_pub },
    nova_private_key       => { type => 'ssh-rsa', key => base64('decode', $pass_nova_ssh_priv) },
    cpu_allocation_ratio   => $cpu_allocation_ratio,
    ram_allocation_ratio   => $ram_allocation_ratio,
    disk_allocation_ratio  => $disk_allocation_ratio,
  }
}
